const { relative } = require('path');
const validate = require('validate-npm-package-name');

const digigovDepsDev = [
  '@digigov/cli',
  '@digigov/cli-build',
  '@digigov/cli-lint',
  '@digigov/cli-test',
  '@digigov/cli-docs',
];

const digigovDeps = [
  '@digigov/react-core',
  '@digigov/docusaurus-preset',
  '@grnet/docusaurus-term-preview',
  '@grnet/docusaurus-glossary-view',
];

module.exports = {
  prompts: require('./prompts'),
  templateData() {
    const pm = this.answers.pm === 'yarn' ? 'yarn' : 'npm';
    const pmRun = this.answers.pm === 'yarn' ? 'yarn' : 'npm run';
    const theme = this.answers.theme === 'digigov' ? 'digigov' : 'docusaurus';
    return {
      pm,
      pmRun,
      theme,
    };
  },

  actions() {
    const validation = validate(this.answers.name);
    validation.warnings &&
      validation.warnings.forEach((warn) => {
        console.warn('Warning:', warn);
      });
    validation.errors &&
      validation.errors.forEach((err) => {
        console.error('Error:', err);
      });
    validation.errors && validation.errors.length && process.exit(1);

    const actions = [
      {
        type: 'add',
        files: '**',
        templateDir: `template/app`,
      },
    ];

    actions.push({
      type: 'add',
      files: '*',
    });

    if (this.answers.theme === 'docusaurus') {
      actions.push({
        type: 'remove',
        files: 'src/pages/index.js',
      });

      actions.push({
        type: 'move',
        patterns: {
          'src/pages/index.classic.js': 'src/pages/index.js',
        },
      });
    } else {
      actions.push(
        {
          type: 'remove',
          files: 'src/pages/index.classic.js',
        },
        {
          type: 'add',
          files: 'src/css/custom.css',
        }
      );
    }

    actions.push({
      type: 'move',
      patterns: {
        gitignore: '.gitignore',
        '_package.json': 'package.json',
        '_.prettierrc.js': '.prettierrc.js',
        '_eslint.config.mjs': 'eslint.config.mjs',
        '_docusaurus.config.js': 'docusaurus.config.js',
      },
    });

    return actions;
  },

  async completed() {
    this.gitInit();

    const { cliOptions = {} } = this.sao.opts;
    if (!cliOptions.noInstall) {
      await this.npmInstall({ npmClient: this.answers.pm });
    }

    const chalk = this.chalk;
    const isNewFolder = this.outDir !== process.cwd();
    const relativeOutFolder = relative(process.cwd(), this.outDir);
    const cdMsg = isNewFolder ? chalk`\t{cyan cd ${relativeOutFolder}}\n` : '';
    const pmRun = this.answers.pm === 'yarn' ? 'yarn' : 'npm run';

    const devArg = this.answers.pm === 'npm' ? '-D' : '--dev';

    console.log(
      chalk`\n🎉  {bold Successfully created project} {cyan ${this.answers.name}}\n`
    );
    console.log(`\n  ${chalk.red("✋ Hodor. HODOR! We're not done yet.")}\n`);
    console.log(
      chalk`  You should change you current to the next project:\n\n${cdMsg}`
    );
    console.log(
      chalk`\n  {bold You should install the following dependencies:} \n\n \t{cyan ${this.answers.pm} add ${digigovDeps.join(' ')}}\n`
    );
    console.log(
      chalk`\n  {bold and also the following devDependencies:} \n\n \t{cyan ${this.answers.pm} add ${devArg} --ignore-engines ${digigovDepsDev.join(' ')}}\n`
    );

    console.log(chalk`  {bold To get started:}\n`);
    console.log(chalk`${cdMsg}\t{cyan ${pmRun} start}\n`);

    console.log(chalk`  {bold To build & start for production:}\n`);
    console.log(chalk`${cdMsg}\t{cyan ${pmRun} build}`);
    console.log(chalk`\t{cyan ${pmRun} serve}\n`);
  },
};
