import React from 'react';
import Layout from '@theme/Layout';
import useDocusaurusContext from '@docusaurus/useDocusaurusContext';
import useBaseUrl from '@docusaurus/useBaseUrl';
import styles from './styles.module.css';
import {
  Masthead,
  Container,
  Heading,
  Paragraph,
  CallToAction,
  Grid,
} from '@digigov/react-core';

const features = [
  {
    title: 'Easy to Use',
    imageUrl: 'img/undraw_docusaurus_mountain.svg',
    description: (
      <>
        Docusaurus was designed from the ground up to be easily installed and
        used to get your website up and running quickly.
      </>
    ),
  },
  {
    title: 'Focus on What Matters',
    imageUrl: 'img/undraw_docusaurus_tree.svg',
    description: (
      <>
        Docusaurus lets you focus on your docs, and we&apos;ll do the chores. Go
        ahead and move your docs into the <code>docs</code> directory.
      </>
    ),
  },
  {
    title: 'Powered by React',
    imageUrl: 'img/undraw_docusaurus_react.svg',
    description: (
      <>
        Extend or customize your website layout by reusing React. Docusaurus can
        be extended while reusing the same header and footer.
      </>
    ),
  },
];

function Feature({ imageUrl, title, description }) {
  const imgUrl = useBaseUrl(imageUrl);
  return (
    <div>
      {imgUrl && (
        <div className="text--center">
          <img className={styles.featureImage} src={imgUrl} alt={title} />
        </div>
      )}
      <Heading size="md">{title}</Heading>
      <Paragraph>{description}</Paragraph>
    </div>
  );
}

function Home() {
  const context = useDocusaurusContext();
  const { siteConfig = {} } = context;
  return (
    <Layout
      title={`Hello from ${siteConfig.title}`}
      description="Description will go into a meta tag in <head />"
    >
      <Masthead>
        <Container>
          <Grid item xs={12} md={8}>
            <Heading size="xl">{siteConfig.title}</Heading>
            <Paragraph>{siteConfig.tagline}</Paragraph>
            <CallToAction href={useBaseUrl('docs/style-guide')}>Start here</CallToAction>
          </Grid>
        </Container>
      </Masthead>
      <Container grid={false}>
        {features && features.length > 0 && (
          <Grid container spacing={4}>
            {features.map((props, idx) => (
              <Grid key={idx} item xs={12} md={6}>
                <Feature {...props} />
              </Grid>
            ))}
          </Grid>
        )}
      </Container>
    </Layout>
  );
}

export default Home;
